@@ -1444,23 +1444,15 @@ _gedit_tab_new_from_uri (const gchar         *uri,
 {
 	GeditTab *tab;
 
-	gboolean ret;
-	
 	g_return_val_if_fail (uri != NULL, NULL);
-	
-	tab = GEDIT_TAB (_gedit_tab_new ());
-		
-	ret = _gedit_tab_load (tab,
-			       uri,
-			       encoding,
-			       line_pos,
-			       create);
 
-	if (!ret)
-	{
-		g_object_unref (tab);
-		return NULL;
-	}
+	tab = GEDIT_TAB (_gedit_tab_new ());
+
+	_gedit_tab_load (tab,
+			 uri,
+			 encoding,
+			 line_pos,
+			 create);
 
 	return GTK_WIDGET (tab);
 }		
@@ -1608,10 +1600,11 @@ static GdkPixbuf *
 resize_icon (GdkPixbuf *pixbuf,
 	     gint       size)
 {
-	guint width, height;
-	
+	gint width, height;
+
 	width = gdk_pixbuf_get_width (pixbuf); 
 	height = gdk_pixbuf_get_height (pixbuf);
+
 	/* if the icon is larger than the nominal size, scale down */
 	if (MAX (width, height) > size) 
 	{
@@ -1768,7 +1761,7 @@ gedit_tab_get_from_document (GeditDocument *doc)
 	return (res != NULL) ? GEDIT_TAB (res) : NULL;
 }
 
-gboolean
+void
 _gedit_tab_load (GeditTab            *tab,
 		 const gchar         *uri,
 		 const GeditEncoding *encoding,
@@ -1777,25 +1770,25 @@ _gedit_tab_load (GeditTab            *tab,
 {
 	GeditDocument *doc;
 
-	g_return_val_if_fail (GEDIT_IS_TAB (tab), FALSE);
-	g_return_val_if_fail (tab->priv->state == GEDIT_TAB_STATE_NORMAL, FALSE);
+	g_return_if_fail (GEDIT_IS_TAB (tab));
+	g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_NORMAL);
 
 	doc = gedit_tab_get_document (tab);
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
 	gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING);
 
 	tab->priv->tmp_line_pos = line_pos;
 	tab->priv->tmp_encoding = encoding;
-	
+
 	if (tab->priv->auto_save_timeout > 0)
 		remove_auto_save_timeout (tab);
 
-	return gedit_document_load (doc,
-				    uri,
-				    encoding,
-				    line_pos,
-				    create);
+	gedit_document_load (doc,
+			     uri,
+			     encoding,
+			     line_pos,
+			     create);
 }
 
 void
