@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-docinfo-plugin.c,v 1.2 2005/12/12 17:27:59 pborelli Exp $
+ * $Id: gedit-docinfo-plugin.c,v 1.3 2006/02/01 08:32:47 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -70,13 +70,11 @@ static void docinfo_dialog_response_cb (GtkDialog   *widget,
 					GeditWindow *window);
 
 static void
-docinfo_dialog_destroy_cb (GtkObject *obj,
-			   gpointer  data_pointer)
+docinfo_dialog_destroy_cb (GtkObject  *obj,
+			   WindowData *data)
 {
 	gedit_debug (DEBUG_PLUGINS);
 
-	WindowData *data = (WindowData *) data_pointer;
-
 	if (data != NULL)
 	{
 		g_free (data->dialog);
