@@ -19,6 +19,7 @@
 __all__ = ('Manager', )
 
 import gtk
+import gtksourceview as gsv
 from gtk import glade
 import os.path
 from gettext import gettext as _
@@ -30,12 +31,10 @@ class Manager:
 	GLADE_FILE = os.path.join(os.path.dirname(__file__), "tools.glade")
 	GCONF_DIR = '/apps/gedit-2/plugins/tools'
 
-
 	LABEL_COLUMN = 0 # For Combo and Tree
 	NODE_COLUMN  = 1 # For Tree only
 	NAME_COLUMN = 1  # For Combo only
 
-
 	__shared_state = None
 
 	combobox_items = {
@@ -80,6 +79,7 @@ class Manager:
 		}
 		
 		# Load the "main-window" widget from the glade file.
+		glade.set_custom_handler(self.custom_handler)
 		self.ui = glade.XML(self.GLADE_FILE, 'tool-manager-dialog')
 		self.ui.signal_autoconnect(callbacks)
 		self.dialog = self.ui.get_widget('tool-manager-dialog')
@@ -127,6 +127,21 @@ class Manager:
 		"""Convenience function to get a widget from its name"""
 		return self.ui.get_widget(key)
 
+	def custom_handler(self, xml, function_name, widget_name,
+	                   str1, str2, int1 , int2):
+		if function_name == 'create_commands':
+			buf = gsv.SourceBuffer()
+			manager = gsv.SourceLanguagesManager()
+			language = manager.get_language_from_mime_type('text/x-shellscript')
+			buf.set_language(language)
+			buf.set_highlight(True)
+			view = gsv.SourceView(buf)
+			view.set_wrap_mode(gtk.WRAP_WORD)
+			view.show()
+			return view
+		else:
+			return None
+
 	def set_active_by_name(self, combo_name, option_name):
 		combo = self[combo_name]
 		model = combo.get_model()
@@ -233,7 +248,7 @@ class Manager:
 	def on_view_selection_changed(self, selection, userdata):
 		self.save_current_tool()
 		piter, node = self.get_selected_tool()
-		
+
 		self['remove-tool-button'].set_sensitive(piter is not None)
 
 		if node is not None:
@@ -258,9 +273,13 @@ class Manager:
  		                                            mod, 
  		                                            self.current_node)
  		if tool is not None:
- 			message_dialog(self.dlg, gtk.MESSAGE_ERROR,
- 			               __('This accelerator is already bound to %s') %
- 			                  self.current_node.get('label'))
+ 			dialog = gtk.MessageDialog(self.dialog,
+ 			                           gtk.DIALOG_MODAL,
+ 			                           gtk.MESSAGE_ERROR,
+ 			                           gtk.BUTTONS_OK,
+ 			                           _('This accelerator is already bound to %s') % self.current_node.get('label'))
+			dialog.run()
+			dialog.destroy()
  			return False
  		
 		name = gtk.accelerator_name(keyval, mod)
@@ -274,7 +293,9 @@ class Manager:
 		mask = event.state & gtk.accelerator_get_default_mod_mask()
 
 		if event.keyval == gtk.keysyms.Escape:
-			entry.set_text(self.current_node.get('accelerator'))
+			entry.set_text(
+			           default(self.current_node.get('accelerator'),
+			                   ''))
 			self['commands'].grab_focus()
 			return True
 		elif event.keyval == gtk.keysyms.Delete \
@@ -305,9 +326,9 @@ class Manager:
 		if self.current_node is None:
 			return
 		if self.current_node.get('accelerator'):
-			entry.set_text('Type a new accelerator, or press Backspace to clear')
+			entry.set_text(_('Type a new accelerator, or press Backspace to clear'))
 		else:
-			entry.set_text('Type a new accelerator')
+			entry.set_text(_('Type a new accelerator'))
 	
 	def on_accelerator_focus_out(self, entry, event):
 		if self.current_node is not None:
@@ -315,7 +336,7 @@ class Manager:
 
 	def on_tool_manager_dialog_response(self, dialog, response):
 		if response == gtk.RESPONSE_HELP:
-			# Show help
+			gedit.help_display(self.dialog, 'gedit.xml', 'gedit-plugins')
 			return
 
 		self.save_current_tool()
